@@ -43,11 +43,13 @@ class xdict(dict):
         
         try:
             return dict.__getitem__(self, k)
-        except KeyError:
-            if hasattr(self, k):
+        except KeyError, e:
+            try:
                 return object.__getattribute__(self, k)
-            v = self[k] = type(self)()
-            return v
+            except AttributeError:
+                raise e
+                #v = self[k] = type(self)()
+                #return v
         
     def __getattr__(self, k):
         try:
@@ -67,7 +69,11 @@ class xdict(dict):
     def __setitem__(self, k, v):
         if isinstance(k, (str, unicode)) and '.' in k:
             k, rest = k.split('.', 1)
-            self[k][rest] = v
+            try:
+                child = self[k]
+            except KeyError:
+                self[k] = child = type(self)()
+            child[rest] = v
         else:
             if isinstance(v, dict) and not isinstance(v, xdict):
                 v = xdict(v)
